pub struct Awake(/* private fields */);Expand description
Whether a scope is awake, for something it owns to ask on its own.
Held rather than the scope itself, so that a timer the scope owns can ask from off the scope’s own code paths.
Implementations